#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for reading in a similarity Matrix file.

@author: mark
"""

import logging
import csv
import numpy as np

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def parse_similarity_matrix_file(filename):
    """This reads a file in to a dictionary, containing the labels and the
    similarity matrix.
    """
    file_lines = read_similarity_file(filename)
    solvent_names = read_solvent_names(file_lines[0])
    similarity_matrix = None
    matrix_lines = file_lines[1:]
    for line_number in range(len(matrix_lines)):
        solvent_name = solvent_names[line_number]
        if line_number == 0:
            similarity_matrix = read_similarity_matrix_line(solvent_name,
                                                                matrix_lines[line_number])
        else:
            similarity_matrix_line = read_similarity_matrix_line(solvent_name,
                                                             matrix_lines[line_number])
            similarity_matrix = np.row_stack((similarity_matrix,
                                            similarity_matrix_line))
    return {"labels": solvent_names,
            "value_matrix": similarity_matrix}
        

def read_similarity_matrix_line(solvent_name, input_line):
    """This reads in a line and checks that the solvent ids match.
    """
    if solvent_name == input_line[0]:
        return np.array([float(x) for x in input_line[1:]])
    else:
        raise ValueError("incorrect solvent ID")

def read_solvent_names(solvent_name_line):
    """This reads in the solvent names in the first line.
    """
    return solvent_name_line[1:]

def read_similarity_file(filename):
    """This reads in the file to a list.
    """
    data_in = []
    with open(filename, "r") as file_in:
        file_contents = csv.reader(file_in, delimiter='\t')
        for line in file_contents:
            data_in.append(line)
    return data_in
